// file      : libxsd-frontend/semantic-graph.hxx
// license   : GNU GPL v2 + exceptions; see accompanying LICENSE file

#ifndef LIBXSD_FRONTEND_SEMANTIC_GRAPH_HXX
#define LIBXSD_FRONTEND_SEMANTIC_GRAPH_HXX

#include <libxsd-frontend/semantic-graph/annotation.hxx>
#include <libxsd-frontend/semantic-graph/any.hxx>
#include <libxsd-frontend/semantic-graph/any-attribute.hxx>
#include <libxsd-frontend/semantic-graph/attribute.hxx>
#include <libxsd-frontend/semantic-graph/attribute-group.hxx>
#include <libxsd-frontend/semantic-graph/complex.hxx>
#include <libxsd-frontend/semantic-graph/compositors.hxx>
#include <libxsd-frontend/semantic-graph/element.hxx>
#include <libxsd-frontend/semantic-graph/element-group.hxx>
#include <libxsd-frontend/semantic-graph/elements.hxx>
#include <libxsd-frontend/semantic-graph/enumeration.hxx>
#include <libxsd-frontend/semantic-graph/fundamental.hxx>
#include <libxsd-frontend/semantic-graph/list.hxx>
#include <libxsd-frontend/semantic-graph/namespace.hxx>
#include <libxsd-frontend/semantic-graph/particle.hxx>
#include <libxsd-frontend/semantic-graph/schema.hxx>
#include <libxsd-frontend/semantic-graph/union.hxx>

#endif  // LIBXSD_FRONTEND_SEMANTIC_GRAPH_HXX
